@@ -1,4 +1,5 @@
 import logging
+import os
 from pytest import (
     raises, fixture
 )
@@ -35,6 +36,7 @@ class TestSystemPrepare:
             description='../data/example_config.xml',
             derived_from='derived/description'
         )
+        self.description_dir = os.path.dirname(description.description)
         self.xml = description.load()
 
         self.manager = mock.MagicMock(
@@ -290,7 +292,9 @@ class TestSystemPrepare:
         )
         self.manager.process_install_requests_bootstrap.assert_called_once_with(
         )
-        mock_tar.assert_called_once_with('../data/bootstrap.tgz')
+        mock_tar.assert_called_once_with(
+            '{0}/bootstrap.tgz'.format(self.description_dir)
+        )
         tar.extract.assert_called_once_with('root_dir')
         self.manager.post_process_install_requests_bootstrap.assert_called_once_with()
 
